﻿using System.ComponentModel;
using System.Runtime.CompilerServices;

namespace SfSchedule.Models
{
    public class User : INotifyPropertyChanged
    {
        #region INotifyPropertyChanged
        public event PropertyChangedEventHandler PropertyChanged;
        void Set<T>(ref T field, T value, [CallerMemberName] string propertyName = "")
        {
            if (!Equals(field, value))
            {
                field = value;
                if (!string.IsNullOrWhiteSpace(propertyName) && PropertyChanged != null)
                    PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
            }
        }
        #endregion
        private int _Id;
        public int Id { get => _Id; set => Set(ref _Id, value); }
        private string _Name;
        public string Name { get => _Name; set => Set(ref _Name, value); }
        private string _DisplayName;
        public string DisplayName { get => _DisplayName; set => Set(ref _DisplayName, value); }

        /// <summary>
        /// Read only property to expose the resource type name
        /// </summary>
        public string TypeName => "Appointments";
    }
}
