﻿using SfSchedule.Models;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Runtime.CompilerServices;

namespace SfSchedule.ViewModels
{
    public class MainViewModel : INotifyPropertyChanged
    {
        #region INotifyPropertyChanged
        public event PropertyChangedEventHandler PropertyChanged;
        void Set<T>(ref T field, T value, [CallerMemberName] string propertyName = "")
        {
            if (!Equals(field, value))
            {
                field = value;
                if (!string.IsNullOrWhiteSpace(propertyName) && PropertyChanged != null)
                    PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
            }
        }
        #endregion
        private ObservableCollection<User> _Users;
        public ObservableCollection<User> Users { get => _Users; set => Set(ref _Users, value); }
        private ObservableCollection<Appointment> _Appointments;
        public ObservableCollection<Appointment> Appointments { get => _Appointments; set => Set(ref _Appointments, value); }

        public MainViewModel()
        {
            var users = new List<User>();
            var appointments = new List<Appointment>();
            //Get date of first day in the month.
            var firstDay = DateTime.Today;
            firstDay = firstDay.AddDays(1 - firstDay.Day);
            int appointmentId = 1;
            var rnd = new Random();
            for (int userId = 1; userId < 4; userId++)
            {
                var user = new User()
                {
                    Id = userId,
                    Name = "User" + userId.ToString(),
                    DisplayName = "User " + userId.ToString()
                };
                users.Add(user);
                var date = firstDay;
                do
                {
                    for (int i = 0; i < 5; i++)
                    {
                        var appointment = new Appointment()
                        {
                            Id = appointmentId,
                            UserId = user.Id,
                            Subject = "Appointment No. " + appointmentId.ToString(),
                            Notes = "Appointment for user:\n" + user.DisplayName
                        };
                        appointment.Starts = date.AddMinutes(rnd.Next(1, 40) * 30);
                        appointment.Ends = appointment.Starts.AddMinutes(rnd.Next(1, 3) * 30);
                        appointment.Resources.Add(user);
                        appointments.Add(appointment);
                        appointmentId += 1;
                    }
                    date = date.AddDays(1);
                } while (date.Day != 1);
            }
            Users = new ObservableCollection<User>(users);
            Appointments = new ObservableCollection<Appointment>(appointments);
        }
    }
}
